module Bondora
  class API
    include HTTParty

    # Create new API client
    #
    # @param auth_code [String] authorization code
    # @param sandbox [Bool] mode switch
    # @return [Object] Bondora::API object
    def initialize(auth_code, *sandbox)
      self.class.headers 'Authorization' => "Bearer #{auth_code}"

      if sandbox
        self.class.base_uri 'https://api-sandbox.bondora.com/api/v1'
      else
        self.class.base_uri 'https://api.bondora.com/api/v1'
      end
    end


    # Get all auctions
    #
    # @return [String] all auctions as JSON string.
    def auctions
      self.class.get('/auctions').to_json
    end

    # Get auction for specified auction
    #
    # @param auction_id [String] auction id
    # @return [String] specified auction as JSON string.
    def auction(auction_id)
      self.class.get("/auction/#{auction_id}").to_json
    end

    # Get all secondary market offers
    #
    # @return [String] all secondary market offers as JSON string.
    def secondarymarket
      self.class.get('/secondarymarket').to_json
    end

    # Get secondary market item details
    #
    # @param item_id [String] secondary market item id
    # @return [String] secondary market item details as JSON string.
    def secondarymarket_item(item_id)
      self.class.get("/secondarymarket/#{item_id}").to_json
    end

    # Get loanpart details
    #
    # @param loanpart_id [String] loanpart id
    # @return [String] loanpart details as JSON string.
    def loanpart(loanpart_id)
      self.class.get("/loanpart/#{loanpart_id}").to_json
    end

    # Get account balance details
    #
    # @return [String] account balance details as JSON string.
    def balance
      self.class.get('/account/balance').to_json
    end

    # Get account investments
    #
    # @return [String] investments as JSON string.
    def investments
      self.class.get('/account/investments').to_json
    end


=begin
# seems not to work
    def eventlog(date_from, date_to, type, ip_address, page_size, page_nr)
      options = { query: {
          date_from: date_from,
          date_to: date_to,
          type: type,
          ip_address: ip_address,
          page_size: page_size,
          page_nr: page_nr
        }
      }

      self.class.get("/eventlog", options)
    end
=end

    # Get bids
    #
    # @return [String] bids as JSON string.
    def bids
      self.class.get('/bids').to_json
    end

    # Get bid details
    #
    # @param bid_id [String] bid id
    # @return [String] bid details as JSON string.
    def bid(bid_id)
      self.class.get("/bid/#{bid_id}").to_json
    end

    # Get loandatasets
    #
    # @return [String] loandatasets as JSON string.
    def loandataset
      self.class.get('/loandataset').to_json
    end

    # Get reports
    #
    # @return [String] reports as JSON string.
    def reports
      self.class.get('/reports').to_json
    end

    # Get report details
    #
    # @param report_id [String] report id
    # @return [String] report details as JSON string.
    def report(report_id)
      self.class.get("/report/#{report_id}").to_json
    end
  end
end
